# pygui
pygui is a cross-platform GUI framwork, built on top of Pyglet. It is currently
in early stage of development. The aim is to build a simple pythonic API that
could be used to build UI apps and games.
